summaryrefslogtreecommitdiffstats
path: root/lib/pilotAddress.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/pilotAddress.h')
-rw-r--r--lib/pilotAddress.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/lib/pilotAddress.h b/lib/pilotAddress.h
index 94ae3f6..f5c2bcb 100644
--- a/lib/pilotAddress.h
+++ b/lib/pilotAddress.h
@@ -182,9 +182,9 @@ public:
* - phone[6] = Pager
* - phone[7] = Mobile
*
- * Apparently, this order is kept for all languages, just with localized
+ * Aptqparently, this order is kept for all languages, just with localized
* strings. The implementation of the internal methods will assume
- * this order is kept. In other languages, main can tqreplaced with
+ * this order is kept. In other languages, main can replaced with
* Corporation.
*/
class KDE_EXPORT PilotAddress : public PilotRecordBase
@@ -198,11 +198,11 @@ public:
virtual ~PilotAddress();
/** Returns a text representation of the address. If @p richText is true, the
* text will be formatted with Qt-HTML tags. The AppInfo structure @p info
* is used to figure out the phone labels; if it is NULL then bogus labels are
* used to identify phone types.
*/
- TQString getTextRepresentation(const PilotAddressInfo *info, Qt::TextFormat richText) const;
+ TQString getTextRepresentation(const PilotAddressInfo *info, TQt::TextFormat richText) const;
/**
* @param text set the field value
@@ -225,7 +225,7 @@ public:
}
}
- /** Returns the text value of a given field @p field (or TQString::null
+ /** Returns the text value of a given field @p field (or TQString()
* if there is no such field).
*/
TQString getField(int field) const;
@@ -198,11 +198,11 @@ public:
virtual ~PilotAddress();
/** Returns a text representation of the address. If @p richText is true, the
- * text will be formatted with Qt-HTML tags. The AppInfo structure @p info
+ * text will be formatted with TQt-HTML tags. The AppInfo structure @p info
* is used to figure out the phone labels; if it is NULL then bogus labels are
* used to identify phone types.